@@ -76,7 +76,7 @@ def Inputfilegui(title, path=None):
     th = threading.Thread(target=subp.th1, args=([filelist, title, path, event]))
     th.start()
     try:
-        while k != "\n":
+        while k != "\n" and k != "q":
             print("\033[" + str(terminal_size[1]) + ";1H┗" + "━" * (terminal_size[0] - 2) + "┛", end="")
             print("\033[4;1H", end="")
             if lenfilelist != -1:
@@ -189,12 +189,15 @@ def Inputfilegui(title, path=None):
                 th = threading.Thread(target=subp.th1, args=([filelist, title, path, event]))
                 th.start()
     except KeyboardInterrupt:
-        pass
+        event.set()
+        return -2
     else:
         reset()
         event.set()
-        return filelist[select]
-    event.set()
+        if k != "q":
+            return filelist[select]
+        else:
+            return -1
 
 
 def Inputfile(text, textcolor="\033[38;5;10m"):
